@@ -9,17 +9,48 @@ use vcpkg;
 
 #[cfg(windows)]
 fn find_tesseract_system_lib() -> Vec<String> {
-    let lib = vcpkg::Config::new().find_package("tesseract").unwrap();
+    println!("cargo:rerun-if-env-changed=TESSERACT_INCLUDE_PATHS");
+    println!("cargo:rerun-if-env-changed=TESSERACT_LINK_PATHS");
+    println!("cargo:rerun-if-env-changed=TESSERACT_LINK_LIBS");
 
-    vec![lib
-        .include_paths
-        .iter()
-        .map(|x| x.to_string_lossy())
-        .collect::<String>()]
+    let vcpkg = || {
+        let lib = vcpkg::Config::new().find_package("tesseract").unwrap();
+
+        vec![lib
+            .include_paths
+            .iter()
+            .map(|x| x.to_string_lossy())
+            .collect::<String>()]
+    };
+
+    let include_paths = env::var("TESSERACT_INCLUDE_PATHS").ok();
+    let include_paths = include_paths.as_deref().map(|x| x.split(','));
+    let link_paths = env::var("TESSERACT_LINK_PATHS").ok();
+    let link_paths = link_paths.as_deref().map(|x| x.split(','));
+    let link_libs = env::var("TESSERACT_LINK_LIBS").ok();
+    let link_libs = link_libs.as_deref().map(|x| x.split(','));
+    if let (Some(include_paths), Some(link_paths), Some(link_libs)) =
+        (include_paths, link_paths, link_libs)
+    {
+        for link_path in link_paths {
+            println!("cargo:rustc-link-search={}", link_path)
+        }
+
+        for link_lib in link_libs {
+            println!("cargo:rustc-link-lib={}", link_lib)
+        }
+
+        include_paths.map(|x| x.to_string()).collect::<Vec<_>>()
+    } else {
+        vcpkg()
+    }
 }
 
-// On macOS, we sometimes need additional search paths, which we get using pkg-config
-#[cfg(target_os = "macos")]
+// we sometimes need additional search paths, which we get using pkg-config
+// we can use tesseract installed anywhere on Linux.
+// if you change install path(--prefix) to `configure` script.
+// set `export PKG_CONFIG_PATH=/path-to-lib/pkgconfig` before.
+#[cfg(any(target_os = "macos", target_os = "linux"))]
 fn find_tesseract_system_lib() -> Vec<String> {
     let pk = pkg_config::Config::new().probe("tesseract").unwrap();
     // Tell cargo to tell rustc to link the system proj shared library.
@@ -40,7 +71,7 @@ fn find_tesseract_system_lib() -> Vec<String> {
         .collect::<Vec<String>>()
 }
 
-#[cfg(all(not(windows), not(target_os = "macos")))]
+#[cfg(all(not(windows), not(target_os = "macos"), not(target_os = "linux")))]
 fn find_tesseract_system_lib() -> Vec<String> {
     println!("cargo:rustc-link-lib=tesseract");
     vec![]
